bayespy.inference.vmp.nodes.wishart.WishartDistribution.compute_message_to_parent
=================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.wishart

.. automethod:: WishartDistribution.compute_message_to_parent